<?php

namespace FiloBlu\ScratchAndWin\Model;

class ScratchAndWinDetails extends \Magento\Framework\Model\AbstractModel {

    const CACHE_TAG = 'fb_scratchandwin';

    protected $_cacheTag = self::CACHE_TAG;

    protected $scratchAndWinDetailsCollectionFactory;

    public function __construct(        
        \Magento\Framework\Model\Context $context,
        \Magento\Framework\Registry $registry,
        \FiloBlu\ScratchAndWin\Model\ResourceModel\ScratchAndWinDetails\CollectionFactory $scratchAndWinDetailsCollectionFactory,
        \Magento\Framework\Model\ResourceModel\AbstractResource $resource = null,
        \Magento\Framework\Data\Collection\AbstractDb $resourceCollection = null,
        array $data = []
    ) {    
        $this->scratchAndWinDetailsCollectionFactory = $scratchAndWinDetailsCollectionFactory;    
        parent::__construct($context, $registry, $resource, $resourceCollection, $data);
    }

    /**
     * Initialize resource model
     *
     * @return void
     */
    protected function _construct() {
        $this->_init('FiloBlu\ScratchAndWin\Model\ResourceModel\ScratchAndWinDetails');
    }

    public function getAvailableStatuses() {
        return array(
            0 => "Disabled",
            1 => "Enabled"
        );
    }        

    public function getScratchAndWinIdRelations($id) {
        
        $collection = $this->scratchAndWinDetailsCollectionFactory->create();
        $collection->addFieldToFilter('id', ["eq" => $id]);            
    
        $collection->getSelect()->joinInner(
            array('related' => $collection->getTable('filoblu_scratchandwin_relations')),
            'related.filoblu_scratchandwin_details_id=main_table.id',
            array('filoblu_scratchandwin_id')
        );

        //$collection->addFieldToSelect('related.filoblu_scratchandwin_id');            

        $this->_cacheTag = [];        

        foreach($collection as $item) {            
            $this->_cacheTag[] = self::CACHE_TAG . '_' . $item->getFilobluScratchandwinId();
        }

        return $this->_cacheTag;
    }

    public function save()
    {

        $this->getScratchAndWinIdRelations($this->getId());
        return parent::save();
    }

    public function afterLoad()
    {
        $this->getScratchAndWinIdRelations($this->getId());
        return parent::_afterLoad();
    }

    public function beforeDelete()
    {
        $this->getScratchAndWinIdRelations($this->getId());
        return parent::beforeDelete();
    }

}
